@@ -19,7 +19,6 @@ typedef Eo Ecore_Audio_Out_Sndfile;
  */
 #define ECORE_AUDIO_OUT_SNDFILE_CLASS ecore_audio_out_sndfile_class_get()
 
-EWAPI const Eo_Class *ecore_audio_out_sndfile_class_get(void);
-
+EWAPI const Efl_Class *ecore_audio_out_sndfile_class_get(void);
 
 #endif
