@@ -13,18 +13,13 @@ typedef Eo Efl_Control;
 
 
 #endif
-#define EFL_CONTROL_INTERFACE efl_control_interface_get()
-
-EWAPI const Eo_Class *efl_control_interface_get(void);
-
-/**
- * @brief Control the priority of the object.
- *
- * @return The priority of the object
+/** Efl control interface
  *
  * @ingroup Efl_Control
  */
-EOAPI int efl_control_priority_get(const Eo *obj);
+#define EFL_CONTROL_INTERFACE efl_control_interface_get()
+
+EWAPI const Efl_Class *efl_control_interface_get(void);
 
 /**
  * @brief Control the priority of the object.
@@ -36,13 +31,13 @@ EOAPI int efl_control_priority_get(const Eo *obj);
 EOAPI void efl_control_priority_set(Eo *obj, int priority);
 
 /**
- * @brief Controls whether the object is suspended or not.
+ * @brief Control the priority of the object.
  *
- * @return Controls whether the object is suspended or not.
+ * @return The priority of the object
  *
  * @ingroup Efl_Control
  */
-EOAPI Eina_Bool efl_control_suspend_get(const Eo *obj);
+EOAPI int efl_control_priority_get(const Eo *obj);
 
 /**
  * @brief Controls whether the object is suspended or not.
@@ -53,5 +48,13 @@ EOAPI Eina_Bool efl_control_suspend_get(const Eo *obj);
  */
 EOAPI void efl_control_suspend_set(Eo *obj, Eina_Bool suspend);
 
+/**
+ * @brief Controls whether the object is suspended or not.
+ *
+ * @return Controls whether the object is suspended or not.
+ *
+ * @ingroup Efl_Control
+ */
+EOAPI Eina_Bool efl_control_suspend_get(const Eo *obj);
 
 #endif
