@@ -11,12 +11,16 @@ typedef Eo Efl_Gfx_Buffer;
 #ifndef _EFL_GFX_BUFFER_EO_TYPES
 #define _EFL_GFX_BUFFER_EO_TYPES
 
+/** Graphics buffer access mode
+ *
+ * @ingroup Efl_Gfx_Buffer
+ */
 typedef enum
 {
-  EFL_GFX_BUFFER_ACCESS_MODE_NONE = 0,
-  EFL_GFX_BUFFER_ACCESS_MODE_READ = 1,
-  EFL_GFX_BUFFER_ACCESS_MODE_WRITE = 2,
-  EFL_GFX_BUFFER_ACCESS_MODE_COW = 4 /** Forces copy-on-write if already mapped
+  EFL_GFX_BUFFER_ACCESS_MODE_NONE = 0, /**< No buffer access */
+  EFL_GFX_BUFFER_ACCESS_MODE_READ = 1, /**< Read access to buffer */
+  EFL_GFX_BUFFER_ACCESS_MODE_WRITE = 2, /**< Write aces to buffer */
+  EFL_GFX_BUFFER_ACCESS_MODE_COW = 4 /**< Forces copy-on-write if already mapped
                                       * as read-only. Requires write. */
 } Efl_Gfx_Buffer_Access_Mode;
 
@@ -28,17 +32,7 @@ typedef enum
  */
 #define EFL_GFX_BUFFER_INTERFACE efl_gfx_buffer_interface_get()
 
-EWAPI const Eo_Class *efl_gfx_buffer_interface_get(void);
-
-/**
- * @brief Rectangular size of the pixel buffer as allocated in memory.
- *
- * @param[out] w Width in pixels.
- * @param[out] h Height in pixels.
- *
- * @ingroup Efl_Gfx_Buffer
- */
-EOAPI void efl_gfx_buffer_size_get(const Eo *obj, int *w, int *h);
+EWAPI const Efl_Class *efl_gfx_buffer_interface_get(void);
 
 /**
  * @brief Rectangular size of the pixel buffer as allocated in memory.
@@ -52,6 +46,16 @@ EOAPI void efl_gfx_buffer_size_get(const Eo *obj, int *w, int *h);
  */
 EOAPI void efl_gfx_buffer_size_set(Eo *obj, int w, int h);
 
+/**
+ * @brief Rectangular size of the pixel buffer as allocated in memory.
+ *
+ * @param[out] w Width in pixels.
+ * @param[out] h Height in pixels.
+ *
+ * @ingroup Efl_Gfx_Buffer
+ */
+EOAPI void efl_gfx_buffer_size_get(const Eo *obj, int *w, int *h);
+
 /**
  * @brief The colorspace defines how pixels are encoded in the image in memory.
  *
@@ -66,24 +70,12 @@ EOAPI void efl_gfx_buffer_size_set(Eo *obj, int w, int h);
  *
  * See @ref Efl_Gfx_Colorspace for more information on the supported formats.
  *
+ * @return Colorspace
+ *
  * @ingroup Efl_Gfx_Buffer
  */
 EOAPI Efl_Gfx_Colorspace efl_gfx_buffer_colorspace_get(const Eo *obj);
 
-/**
- * @brief Indicates whether the alpha channel should be used.
- *
- * This does not indicate whether the image source file contains an alpha
- * channel, only whether to respect it or discard it.
- *
- * Retrieve whether alpha channel data is used on this object.
- *
- * @return Whether to use alpha channel ($true) data or not ($false).
- *
- * @ingroup Efl_Gfx_Buffer
- */
-EOAPI Eina_Bool efl_gfx_buffer_alpha_get(const Eo *obj);
-
 /**
  * @brief Indicates whether the alpha channel should be used.
  *
@@ -103,6 +95,20 @@ EOAPI Eina_Bool efl_gfx_buffer_alpha_get(const Eo *obj);
  */
 EOAPI void efl_gfx_buffer_alpha_set(Eo *obj, Eina_Bool alpha);
 
+/**
+ * @brief Indicates whether the alpha channel should be used.
+ *
+ * This does not indicate whether the image source file contains an alpha
+ * channel, only whether to respect it or discard it.
+ *
+ * Retrieve whether alpha channel data is used on this object.
+ *
+ * @return Whether to use alpha channel ($true) data or not ($false).
+ *
+ * @ingroup Efl_Gfx_Buffer
+ */
+EOAPI Eina_Bool efl_gfx_buffer_alpha_get(const Eo *obj);
+
 /**
  * @brief Length in bytes of one row of pixels in memory.
  *
@@ -112,10 +118,27 @@ EOAPI void efl_gfx_buffer_alpha_set(Eo *obj, Eina_Bool alpha);
  * When applicable, this will include the @ref efl_gfx_buffer_borders_get as
  * well as potential extra padding.
  *
+ * @return Stride
+ *
  * @ingroup Efl_Gfx_Buffer
  */
 EOAPI int efl_gfx_buffer_stride_get(const Eo *obj);
 
+/**
+ * @brief Mark a sub-region of the given image object to be redrawn.
+ *
+ * This function schedules a particular rectangular region of an image object
+ * to be updated (redrawn) at the next rendering cycle.
+ *
+ * @param[in] x X-offset of the region to be updated.
+ * @param[in] y Y-offset of the region to be updated.
+ * @param[in] w Width of the region to be updated.
+ * @param[in] h Height of the region to be updated.
+ *
+ * @ingroup Efl_Gfx_Buffer
+ */
+EOAPI void efl_gfx_buffer_update_add(Eo *obj, int x, int y, int w, int h);
+
 /**
  * @brief Duplicated pixel borders inside this buffer.
  *
@@ -133,21 +156,6 @@ EOAPI int efl_gfx_buffer_stride_get(const Eo *obj);
  */
 EOAPI void efl_gfx_buffer_borders_get(const Eo *obj, unsigned int *l, unsigned int *r, unsigned int *t, unsigned int *b);
 
-/**
- * @brief Mark a sub-region of the given image object to be redrawn.
- *
- * This function schedules a particular rectangular region of an image object
- * to be updated (redrawn) at the next rendering cycle.
- *
- * @param[in] x X-offset of the region to be updated.
- * @param[in] y Y-offset of the region to be updated.
- * @param[in] w Width of the region to be updated.
- * @param[in] h Height of the region to be updated.
- *
- * @ingroup Efl_Gfx_Buffer
- */
-EOAPI void efl_gfx_buffer_update_add(Eo *obj, int x, int y, int w, int h);
-
 /**
  * @brief Map a region of this buffer for read or write access by the CPU.
  *
@@ -158,24 +166,24 @@ EOAPI void efl_gfx_buffer_update_add(Eo *obj, int x, int y, int w, int h);
  * Note that if the buffer has @ref efl_gfx_buffer_borders_get, then @c x and
  * @c y may be negative.
  *
- * @param[out] length Accessible buffer size in bytes, should not be @c null.
+ * @param[out] slice Pointer to the top-left pixel data.
  * @param[in] mode Specifies whether to map for read-only, write-only or
- * read-write access (OR combinaison of flags).
+ * read-write access (OR combination of flags).
  * @param[in] x X position of the top-left pixel to map, defaults to 0.
  * @param[in] y Y position of the top-left pixel to map, defaults to 0.
  * @param[in] w If 0, defaults to the buffer width.
  * @param[in] h If 0, defaults to the buffer height.
- * @param[in] cspace Requested colorspace. If differen from the internal
+ * @param[in] cspace Requested colorspace. If different from the internal
  * cspace, map should try to convert the data into a new buffer. argb8888 by
  * default.
+ * @param[in] plane Plane ID. 0 by default. Useful for planar formats only.
  * @param[out] stride Returns the length in bytes of a mapped line
  *
- * @return Pointer to the top-left pixel data. Returns @c null in case of
- * failure
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Efl_Gfx_Buffer
  */
-EOAPI void *efl_gfx_buffer_map(Eo *obj, int *length, Efl_Gfx_Buffer_Access_Mode mode, int x, int y, int w, int h, Efl_Gfx_Colorspace cspace, int *stride);
+EOAPI Eina_Bool efl_gfx_buffer_map(Eo *obj, Eina_Rw_Slice *slice, Efl_Gfx_Buffer_Access_Mode mode, int x, int y, int w, int h, Efl_Gfx_Colorspace cspace, int plane, int *stride);
 
 /**
  * @brief Unmap a region of this buffer, and update the internal data if
@@ -183,43 +191,18 @@ EOAPI void *efl_gfx_buffer_map(Eo *obj, int *length, Efl_Gfx_Buffer_Access_Mode
  *
  * EFL will update the internal image if the map had write access.
  *
- * @param[in] data Data pointer returned by a previous call to map
- * @param[in] length Must be the same as returned by map.
+ * @note The @c slice struct does not need to be the one returned by
+ * @ref efl_gfx_buffer_map, only its contents ($mem and @c len) must match. But
+ * after a call to @ref efl_gfx_buffer_unmap the original @c slice structure is
+ * not valid anymore.
  *
- * @return This will return @c false in case of failure (invalid parameters or
- * state of the object).
+ * @param[in] slice Data slice returned by a previous call to map.
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Efl_Gfx_Buffer
  */
-EOAPI Eina_Bool efl_gfx_buffer_unmap(Eo *obj, void *data, int length);
-
-/**
- * @brief Set the pixels for this buffer, or allocate a new memory region.
- *
- * EFL will use @c pixels directly, and update the GPU-side texture if
- * required. This will mark the image as dirty.
- *
- * If @c pixels is @c null, then a new empty buffer will be allocated. If the
- * buffer already had pixel data, the previous image data will be dropped. This
- * is the same as @ref efl_gfx_buffer_copy_set.
- *
- * The memory buffer @c pixels must be large enough to hold @c width x
- * @c height pixels encoded in the colorspace @c cspace.
- *
- * See also @ref efl_gfx_buffer_copy_set if you want EFL to copy the input
- * buffer internally.
- *
- * @param[in] pixels If @c null, allocates an empty buffer
- * @param[in] width
- * @param[in] height
- * @param[in] stride If 0, automatically guessed from the @c width.
- * @param[in] cspace argb8888 by default.
- *
- * @return This function returns @c false in case of failure.
- *
- * @ingroup Efl_Gfx_Buffer
- */
-EOAPI Eina_Bool efl_gfx_buffer_data_set(Eo *obj, void *pixels, int width, int height, int stride, Efl_Gfx_Colorspace cspace);
+EOAPI Eina_Bool efl_gfx_buffer_unmap(Eo *obj, const Eina_Rw_Slice *slice);
 
 /**
  * @brief Set the pixels for this buffer by copying them, or allocate a new
@@ -231,37 +214,69 @@ EOAPI Eina_Bool efl_gfx_buffer_data_set(Eo *obj, void *pixels, int width, int he
  *
  * If @c pixels is @c null, then a new empty buffer will be allocated. If the
  * buffer already had pixel data, the previous image data will be dropped. This
- * is the same as @ref efl_gfx_buffer_data_set.
+ * is the same as @ref efl_gfx_buffer_managed_set.
  *
  * The memory buffer @c pixels must be large enough to hold @c width x
  * @c height pixels encoded in the colorspace @c cspace.
  *
- * @c pixels should not be the return value of @ref efl_gfx_buffer_data_get.
+ * @c slice should not be the return value of @ref efl_gfx_buffer_managed_get.
  *
- * @param[in] pixels If @c null, allocates an empty buffer
- * @param[in] width
- * @param[in] height
+ * @param[in] slice If @c null, allocates an empty buffer
+ * @param[in] width Width
+ * @param[in] height Height
  * @param[in] stride If 0, automatically guessed from the @c width.
  * @param[in] cspace argb8888 by default.
+ * @param[in] plane Plane ID. 0 by default. Useful for planar formats only.
  *
- * @return This function returns @c false in case of failure.
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Efl_Gfx_Buffer
  */
-EOAPI Eina_Bool efl_gfx_buffer_copy_set(Eo *obj, const void *pixels, int width, int height, int stride, Efl_Gfx_Colorspace cspace);
+EOAPI Eina_Bool efl_gfx_buffer_copy_set(Eo *obj, const Eina_Slice *slice, int width, int height, int stride, Efl_Gfx_Colorspace cspace, int plane);
+
+/**
+ * @brief Set the pixels for this buffer, managed externally by the client.
+ *
+ * EFL will use the pixel data directly, and update the GPU-side texture if
+ * required. This will mark the image as dirty. If @c slice is @c null, this
+ * will detach the pixel data.
+ *
+ * If the buffer already had pixel data, the previous image data will be
+ * dropped. This is the same as @ref efl_gfx_buffer_copy_set.
+ *
+ * The memory buffer @c pixels must be large enough to hold @c width x
+ * @c height pixels encoded in the colorspace @c cspace.
+ *
+ * See also @ref efl_gfx_buffer_copy_set if you want EFL to copy the input
+ * buffer internally.
+ *
+ * @param[in] slice If @c null, detaches the previous buffer.
+ * @param[in] width Width
+ * @param[in] height Height
+ * @param[in] stride If 0, automatically guessed from the @c width.
+ * @param[in] cspace argb8888 by default.
+ * @param[in] plane Plane ID. 0 by default. Useful for planar formats only.
+ *
+ * @return @c true on success, @c false otherwise
+ *
+ * @ingroup Efl_Gfx_Buffer
+ */
+EOAPI Eina_Bool efl_gfx_buffer_managed_set(Eo *obj, const Eina_Slice *slice, int width, int height, int stride, Efl_Gfx_Colorspace cspace, int plane);
 
 /**
  * @brief Get a direct pointer to the internal pixel data, if available.
  *
- * This will return @c null unless @ref efl_gfx_buffer_data_set was used to
- * pass in an external data pointer.
+ * This will return @c null unless @ref efl_gfx_buffer_managed_set was used to
+ * pass in an external data pointer. The returned @ref Eina_Slice struct must
+ * be freed by the caller.
  *
- * @note This is different from the legacy API data, which is now replaced by
- * map/unmap.
+ * @param[out] slice Data slice
+ * @param[in] plane Plane ID. 0 by default. Useful for planar formats only.
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Efl_Gfx_Buffer
  */
-EOAPI void *efl_gfx_buffer_data_get(Eo *obj);
-
+EOAPI Eina_Bool efl_gfx_buffer_managed_get(Eo *obj, Eina_Slice *slice, int plane);
 
 #endif
