@@ -19,7 +19,7 @@ typedef Eo Eldbus_Model_Signal;
  */
 #define ELDBUS_MODEL_SIGNAL_CLASS eldbus_model_signal_class_get()
 
-EWAPI const Eo_Class *eldbus_model_signal_class_get(void);
+EWAPI const Efl_Class *eldbus_model_signal_class_get(void);
 
 /**
  * @brief Custom Eldbus_Model_Signal constructor.
@@ -33,5 +33,4 @@ EWAPI const Eo_Class *eldbus_model_signal_class_get(void);
  */
 EOAPI void eldbus_model_signal_constructor(Eo *obj, Eldbus_Proxy *proxy, const Eldbus_Introspection_Signal *signal);
 
-
 #endif
