@@ -23,11 +23,18 @@ typedef Eo Efl_Ui_Layout_Internal_Box;
  */
 #define EFL_UI_LAYOUT_INTERNAL_BOX_CLASS efl_ui_layout_internal_box_class_get()
 
-EWAPI const Eo_Class *efl_ui_layout_internal_box_class_get(void);
+EWAPI const Efl_Class *efl_ui_layout_internal_box_class_get(void);
 
 #ifdef EFL_UI_LAYOUT_INTERNAL_BOX_PROTECTED
-EOAPI void efl_ui_layout_internal_box_real_part_set(Eo *obj, Eo_Base *layout, const char *part);
+/**
+ * @brief Real part property
+ *
+ * @param[in] layout Real part object
+ * @param[in] part Real part name
+ *
+ * @ingroup Efl_Ui_Layout_Internal_Box
+ */
+EOAPI void efl_ui_layout_internal_box_real_part_set(Eo *obj, Efl_Object *layout, const char *part);
 #endif
 
-
 #endif
