@@ -20,8 +20,8 @@ typedef Eo Elm_Entry;
  */
 typedef enum
 {
-  ELM_TEXT_FORMAT_PLAIN_UTF8 = 0, /** Plain UTF8 type */
-  ELM_TEXT_FORMAT_MARKUP_UTF8 /** Markup UTF8 type */
+  ELM_TEXT_FORMAT_PLAIN_UTF8 = 0, /**< Plain UTF8 type */
+  ELM_TEXT_FORMAT_MARKUP_UTF8 /**< Markup UTF8 type */
 } Elm_Text_Format;
 
 /** Input panel (virtual keyboard) layout types. Type of input panel (virtual
@@ -32,27 +32,32 @@ typedef enum
  */
 typedef enum
 {
-  ELM_INPUT_PANEL_LAYOUT_NORMAL = 0, /** Default layout. */
-  ELM_INPUT_PANEL_LAYOUT_NUMBER, /** Number layout. */
-  ELM_INPUT_PANEL_LAYOUT_EMAIL, /** Email layout. */
-  ELM_INPUT_PANEL_LAYOUT_URL, /** URL layout. */
-  ELM_INPUT_PANEL_LAYOUT_PHONENUMBER, /** Phone Number layout. */
-  ELM_INPUT_PANEL_LAYOUT_IP, /** IP layout. */
-  ELM_INPUT_PANEL_LAYOUT_MONTH, /** Month layout. */
-  ELM_INPUT_PANEL_LAYOUT_NUMBERONLY, /** Number Only layout. */
-  ELM_INPUT_PANEL_LAYOUT_INVALID, /** Never use this. */
-  ELM_INPUT_PANEL_LAYOUT_HEX, /** Hexadecimal layout. */
-  ELM_INPUT_PANEL_LAYOUT_TERMINAL, /** Command-line terminal layout including
+  ELM_INPUT_PANEL_LAYOUT_NORMAL = 0, /**< Default layout. */
+  ELM_INPUT_PANEL_LAYOUT_NUMBER, /**< Number layout. */
+  ELM_INPUT_PANEL_LAYOUT_EMAIL, /**< Email layout. */
+  ELM_INPUT_PANEL_LAYOUT_URL, /**< URL layout. */
+  ELM_INPUT_PANEL_LAYOUT_PHONENUMBER, /**< Phone Number layout. */
+  ELM_INPUT_PANEL_LAYOUT_IP, /**< IP layout. */
+  ELM_INPUT_PANEL_LAYOUT_MONTH, /**< Month layout. */
+  ELM_INPUT_PANEL_LAYOUT_NUMBERONLY, /**< Number Only layout. */
+  ELM_INPUT_PANEL_LAYOUT_INVALID, /**< Never use this. */
+  ELM_INPUT_PANEL_LAYOUT_HEX, /**< Hexadecimal layout. */
+  ELM_INPUT_PANEL_LAYOUT_TERMINAL, /**< Command-line terminal layout including
                                     * esc, alt, ctrl key, so on (no
                                     * auto-correct, no auto-capitalization). */
-  ELM_INPUT_PANEL_LAYOUT_PASSWORD, /** Like normal, but no auto-correct, no
+  ELM_INPUT_PANEL_LAYOUT_PASSWORD, /**< Like normal, but no auto-correct, no
                                     * auto-capitalization etc. */
-  ELM_INPUT_PANEL_LAYOUT_DATETIME, /** Date and time layout
+  ELM_INPUT_PANEL_LAYOUT_DATETIME, /**< Date and time layout
                                     *
                                     * @since 1.8 */
-  ELM_INPUT_PANEL_LAYOUT_EMOTICON /** Emoticon layout
-                                   *
-                                   * @since 1.10 */
+  ELM_INPUT_PANEL_LAYOUT_EMOTICON, /**< Emoticon layout
+                                    *
+                                    * @since 1.10 */
+  ELM_INPUT_PANEL_LAYOUT_VOICE /**< Voice layout, but if the IME does not
+                                * support voice layout, then normal layout will
+                                * be shown.
+                                *
+                                * @since 1.19 */
 } Elm_Input_Panel_Layout;
 
 /**
@@ -64,8 +69,8 @@ typedef enum
  */
 typedef enum
 {
-  ELM_INPUT_PANEL_LANG_AUTOMATIC = 0, /** Automatic */
-  ELM_INPUT_PANEL_LANG_ALPHABET /** Alphabet */
+  ELM_INPUT_PANEL_LANG_AUTOMATIC = 0, /**< Automatic */
+  ELM_INPUT_PANEL_LANG_ALPHABET /**< Alphabet */
 } Elm_Input_Panel_Lang;
 
 /**
@@ -77,11 +82,11 @@ typedef enum
  */
 typedef enum
 {
-  ELM_AUTOCAPITAL_TYPE_NONE = 0, /** No auto-capitalization when typing. */
-  ELM_AUTOCAPITAL_TYPE_WORD, /** Autocapitalize each word typed. */
-  ELM_AUTOCAPITAL_TYPE_SENTENCE, /** Autocapitalize the start of each sentence.
+  ELM_AUTOCAPITAL_TYPE_NONE = 0, /**< No auto-capitalization when typing. */
+  ELM_AUTOCAPITAL_TYPE_WORD, /**< Autocapitalize each word typed. */
+  ELM_AUTOCAPITAL_TYPE_SENTENCE, /**< Autocapitalize the start of each sentence.
                                   */
-  ELM_AUTOCAPITAL_TYPE_ALLCHARACTER /** Autocapitalize all letters. */
+  ELM_AUTOCAPITAL_TYPE_ALLCHARACTER /**< Autocapitalize all letters. */
 } Elm_Autocapital_Type;
 
 /** "Return" Key types on the input panel (virtual keyboard). See also
@@ -91,16 +96,16 @@ typedef enum
  */
 typedef enum
 {
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_DEFAULT = 0, /** Default. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_DONE, /** Done. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_GO, /** Go. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_JOIN, /** Join. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_LOGIN, /** Login. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_NEXT, /** Next. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_SEARCH, /** Search string or magnifier icon.
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_DEFAULT = 0, /**< Default. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_DONE, /**< Done. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_GO, /**< Go. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_JOIN, /**< Join. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_LOGIN, /**< Login. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_NEXT, /**< Next. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_SEARCH, /**< Search string or magnifier icon.
                                            */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_SEND, /** Send. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_SIGNIN /** Sign-in
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_SEND, /**< Send. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_SIGNIN /**< Sign-in
                                           *
                                           * @since 1.8 */
 } Elm_Input_Panel_Return_Key_Type;
@@ -113,14 +118,14 @@ typedef enum
  */
 typedef enum
 {
-  ELM_INPUT_HINT_NONE = 0, /** No active hints
+  ELM_INPUT_HINT_NONE = 0, /**< No active hints
                             *
                             * @since 1.12 */
-  ELM_INPUT_HINT_AUTO_COMPLETE = 1 /* 1 << 0 */, /** Suggest word auto
+  ELM_INPUT_HINT_AUTO_COMPLETE = 1 /* 1 >> 0 */, /**< Suggest word auto
                                                   * completion
                                                   *
                                                   * @since 1.12 */
-  ELM_INPUT_HINT_SENSITIVE_DATA = 2 /* 1 << 1 */ /** Typed text should not be
+  ELM_INPUT_HINT_SENSITIVE_DATA = 2 /* 1 >> 1 */ /**< Typed text should not be
                                                   * stored.
                                                   *
                                                   * @since 1.12 */
@@ -135,9 +140,9 @@ typedef enum
  */
 typedef enum
 {
-  ELM_CNP_MODE_MARKUP = 0, /** copy & paste text with markup tag */
-  ELM_CNP_MODE_NO_IMAGE, /** copy & paste text without item(image) tag */
-  ELM_CNP_MODE_PLAINTEXT /** copy & paste text without markup tag */
+  ELM_CNP_MODE_MARKUP = 0, /**< copy & paste text with markup tag */
+  ELM_CNP_MODE_NO_IMAGE, /**< copy & paste text without item(image) tag */
+  ELM_CNP_MODE_PLAINTEXT /**< copy & paste text without markup tag */
 } Elm_Cnp_Mode;
 
 
@@ -171,8 +176,8 @@ EAPI Eina_Bool elm_entry_scrollable_get(const Elm_Entry *obj);
  * explicit Mouse Up event. It doesn't request to show the input panel even
  * though it has focus.
  *
- * @param[in] ondemand If true, the input panel will be shown in case of only
- * Mouse up event. (Focus event will be ignored.)
+ * @param[in] ondemand If @c true, the input panel will be shown in case of
+ * only Mouse up event. (Focus event will be ignored.)
  *
  * @since 1.9
  *
@@ -184,7 +189,7 @@ EAPI void elm_entry_input_panel_show_on_demand_set(Elm_Entry *obj, Eina_Bool ond
  * @brief Get the attribute to show the input panel in case of only an user's
  * explicit Mouse Up event.
  *
- * @return If true, the input panel will be shown in case of only Mouse up
+ * @return If @c true, the input panel will be shown in case of only Mouse up
  * event. (Focus event will be ignored.)
  *
  * @since 1.9
@@ -266,7 +271,7 @@ EAPI void elm_entry_file_text_format_set(Elm_Entry *obj, Elm_Text_Format format)
  *
  * This API can be used if you want to show the alphabet keyboard mode.
  *
- * @param[in] lang language to be set to the input panel.
+ * @param[in] lang Language to be set to the input panel.
  *
  * @ingroup Elm_Entry
  */
@@ -275,7 +280,7 @@ EAPI void elm_entry_input_panel_language_set(Elm_Entry *obj, Elm_Input_Panel_Lan
 /**
  * @brief Get the language mode of the input panel.
  *
- * @return language to be set to the input panel.
+ * @return Language to be set to the input panel.
  *
  * @ingroup Elm_Entry
  */
@@ -290,10 +295,11 @@ EAPI Elm_Input_Panel_Lang elm_entry_input_panel_language_get(const Elm_Entry *ob
  */
 EAPI void elm_entry_selection_handler_disabled_set(Elm_Entry *obj, Eina_Bool disabled);
 
+
 /**
  * @brief Set the input panel layout variation of the entry
  *
- * @param[in] variation layout variation type.
+ * @param[in] variation Layout variation type.
  *
  * @since 1.8
  *
@@ -304,7 +310,7 @@ EAPI void elm_entry_input_panel_layout_variation_set(Elm_Entry *obj, int variati
 /**
  * @brief Get the input panel layout variation of the entry
  *
- * @return layout variation type.
+ * @return Layout variation type.
  *
  * @since 1.8
  *
@@ -393,7 +399,7 @@ EAPI const char *elm_entry_anchor_hover_style_get(const Elm_Entry *obj);
  * pressing enter will break the text into a different line without generating
  * any events.
  *
- * @param[in] single_line If true, the text in the entry will be on a single
+ * @param[in] single_line If @c true, the text in the entry will be on a single
  * line.
  *
  * @ingroup Elm_Entry
@@ -403,7 +409,7 @@ EAPI void elm_entry_single_line_set(Elm_Entry *obj, Eina_Bool single_line);
 /**
  * @brief Get whether the entry is set to be single line.
  *
- * @return If true, the text in the entry will be on a single line.
+ * @return If @c true, the text in the entry will be on a single line.
  *
  * @ingroup Elm_Entry
  */
@@ -415,7 +421,7 @@ EAPI Eina_Bool elm_entry_single_line_get(const Elm_Entry *obj);
  * In password mode, entries are implicitly single line and the display of any
  * text in them is replaced with asterisks (*).
  *
- * @param[in] password If true, password mode is enabled.
+ * @param[in] password If @c true, password mode is enabled.
  *
  * @ingroup Elm_Entry
  */
@@ -424,7 +430,7 @@ EAPI void elm_entry_password_set(Elm_Entry *obj, Eina_Bool password);
 /**
  * @brief Get whether the entry is set to password mode.
  *
- * @return If true, password mode is enabled.
+ * @return If @c true, password mode is enabled.
  *
  * @ingroup Elm_Entry
  */
@@ -533,7 +539,7 @@ EAPI Elm_Input_Hints elm_entry_input_hint_get(const Elm_Entry *obj);
 /**
  * @brief Set the input panel layout of the entry.
  *
- * @param[in] layout layout type.
+ * @param[in] layout Layout type.
  *
  * @ingroup Elm_Entry
  */
@@ -542,7 +548,7 @@ EAPI void elm_entry_input_panel_layout_set(Elm_Entry *obj, Elm_Input_Panel_Layou
 /**
  * @brief Get the input panel layout of the entry.
  *
- * @return layout type.
+ * @return Layout type.
  *
  * @ingroup Elm_Entry
  */
@@ -554,6 +560,9 @@ EAPI Elm_Input_Panel_Layout elm_entry_input_panel_layout_get(const Elm_Entry *ob
  *
  * An input panel displays the string or icon associated with this type.
  *
+ * Regardless of return key type, "activated" event will be generated when
+ * pressing return key in single line entry.
+ *
  * @param[in] return_key_type The type of "return" key on the input panel.
  *
  * @ingroup Elm_Entry
@@ -572,7 +581,7 @@ EAPI Elm_Input_Panel_Return_Key_Type elm_entry_input_panel_return_key_type_get(c
 /**
  * @brief Sets the attribute to show the input panel automatically.
  *
- * @param[in] enabled If true, the input panel is appeared when entry is
+ * @param[in] enabled If @c true, the input panel is appeared when entry is
  * clicked or has a focus.
  *
  * @ingroup Elm_Entry
@@ -582,8 +591,8 @@ EAPI void elm_entry_input_panel_enabled_set(Elm_Entry *obj, Eina_Bool enabled);
 /**
  * @brief Get the attribute to show the input panel automatically.
  *
- * @return If true, the input panel is appeared when entry is clicked or has a
- * focus.
+ * @return If @c true, the input panel is appeared when entry is clicked or has
+ * a focus.
  *
  * @ingroup Elm_Entry
  */
@@ -685,7 +694,7 @@ EAPI void elm_entry_select_region_get(const Elm_Entry *obj, int *start, int *end
  * entry has no text. The return key on the input panel is automatically
  * enabled when the entry has text. The default value is @c false.
  *
- * @param[in] enabled If @c enabled is true, the return key is automatically
+ * @param[in] enabled If @c enabled is @c true, the return key is automatically
  * disabled when the entry has no text.
  *
  * @ingroup Elm_Entry
@@ -696,7 +705,7 @@ EAPI void elm_entry_input_panel_return_key_autoenabled_set(Elm_Entry *obj, Eina_
  * @brief Sets the visibility of the end widget of the entry, set by @ref
  * elm_object_part_content_set(ent, "end", content).
  *
- * @param[in] setting true if the object should be displayed, false if not.
+ * @param[in] setting @c true if the object should be displayed, false if not.
  *
  * @ingroup Elm_Entry
  */
@@ -743,6 +752,8 @@ EAPI void elm_entry_cursor_end_set(Elm_Entry *obj);
  * internal textblock object). This applies to all cursors returned from
  * textblock calls, and all the other derivative values.
  *
+ * @return Textblock object
+ *
  * @ingroup Elm_Entry
  */
 EAPI Efl_Canvas_Object *elm_entry_textblock_get(const Elm_Entry *obj);
@@ -753,14 +764,16 @@ EAPI Efl_Canvas_Object *elm_entry_textblock_get(const Elm_Entry *obj);
  * It's useful if you want to draw something on the cursor (or where it is), or
  * for example in the case of scrolled entry where you want to show the cursor.
  *
- * @param[out] x returned geometry.
- * @param[out] y returned geometry.
- * @param[out] w returned geometry.
- * @param[out] h returned geometry.
+ * @param[out] x X coordinate
+ * @param[out] y Y coordinate
+ * @param[out] w Width
+ * @param[out] h Height
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Elm_Entry
  */
-EAPI Eina_Bool elm_entry_cursor_geometry_get(const Elm_Entry *obj, Evas_Coord *x, Evas_Coord *y, Evas_Coord *w, Evas_Coord *h);
+EAPI Eina_Bool elm_entry_cursor_geometry_get(const Elm_Entry *obj, int *x, int *y, int *w, int *h);
 
 /**
  * @brief Returns the input method context of the entry.
@@ -770,6 +783,8 @@ EAPI Eina_Bool elm_entry_cursor_geometry_get(const Elm_Entry *obj, Evas_Coord *x
  * IMPORTANT: Many functions may change (i.e delete and create a new one) the
  * internal input method context. Do NOT cache the returned object.
  *
+ * @return Input method context
+ *
  * @ingroup Elm_Entry
  */
 EAPI void *elm_entry_imf_context_get(const Elm_Entry *obj);
@@ -782,6 +797,8 @@ EAPI void *elm_entry_imf_context_get(const Elm_Entry *obj);
  * invisible one, such as bold begin or end tag. This function returns whether
  * any format node exists at the current cursor position.
  *
+ * @return @c true if format node exists, @c false otherwise
+ *
  * @ingroup Elm_Entry
  */
 EAPI Eina_Bool elm_entry_cursor_is_format_get(const Elm_Entry *obj);
@@ -794,6 +811,8 @@ EAPI Eina_Bool elm_entry_cursor_is_format_get(const Elm_Entry *obj);
  * not be part of the return value. You must free the string when done with
  * @ref free.
  *
+ * @return Character
+ *
  * @ingroup Elm_Entry
  */
 EAPI char *elm_entry_cursor_content_get(const Elm_Entry *obj) EINA_WARN_UNUSED_RESULT;
@@ -809,11 +828,16 @@ EAPI char *elm_entry_cursor_content_get(const Elm_Entry *obj) EINA_WARN_UNUSED_R
  * modified in any way. If the @c entry object is deleted or its contents are
  * changed, the returned pointer should be considered invalid.
  *
+ * @return Selected string
+ *
  * @ingroup Elm_Entry
  */
 EAPI const char *elm_entry_selection_get(const Elm_Entry *obj);
 
-/** Get if the current cursor position holds a visible format node.
+/**
+ * @brief Get if the current cursor position holds a visible format node.
+ *
+ * @return @c true if position has a visible format, @c false otherwise
  *
  * @ingroup Elm_Entry
  */
@@ -841,7 +865,10 @@ EAPI void elm_entry_select_allow_set(Elm_Entry *obj, Eina_Bool allow);
  */
 EAPI Eina_Bool elm_entry_select_allow_get(const Elm_Entry *obj);
 
-/** This moves the cursor one place to the left within the entry.
+/**
+ * @brief This moves the cursor one place to the left within the entry.
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Elm_Entry
  */
@@ -918,7 +945,10 @@ EAPI void elm_entry_anchor_hover_end(Elm_Entry *obj);
  */
 EAPI void elm_entry_cursor_selection_begin(Elm_Entry *obj);
 
-/** This moves the cursor one line down within the entry.
+/**
+ * @brief This moves the cursor one line down within the entry.
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Elm_Entry
  */
@@ -970,6 +1000,8 @@ EAPI void elm_entry_item_provider_remove(Elm_Entry *obj, Elm_Entry_Item_Provider
  *
  * See also @ref elm_entry_text_style_user_push.
  *
+ * @return Style
+ *
  * @since 1.7
  *
  * @ingroup Elm_Entry
@@ -986,7 +1018,10 @@ EAPI const char *elm_entry_text_style_user_peek(const Elm_Entry *obj);
  */
 EAPI void elm_entry_context_menu_clear(Elm_Entry *obj);
 
-/** This moves the cursor one line up within the entry.
+/**
+ * @brief This moves the cursor one line up within the entry.
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Elm_Entry
  */
@@ -1043,7 +1078,10 @@ EAPI void elm_entry_input_panel_imdata_get(const Elm_Entry *obj, void *data, int
  */
 EAPI void elm_entry_selection_paste(Elm_Entry *obj);
 
-/** This moves the cursor one place to the right within the entry.
+/**
+ * @brief This moves the cursor one place to the right within the entry.
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Elm_Entry
  */
@@ -1092,6 +1130,8 @@ EAPI void elm_entry_selection_cut(Elm_Entry *obj);
  * for which no provider finds anything, and no text is displayed, this
  * function still returns @c false.
  *
+ * @return @c true if empty, @c false otherwise
+ *
  * @ingroup Elm_Entry
  */
 EAPI Eina_Bool elm_entry_is_empty(const Elm_Entry *obj);
@@ -1196,4 +1236,16 @@ EAPI void elm_entry_context_menu_item_add(Elm_Entry *obj, const char *label, con
  */
 EAPI void elm_entry_markup_filter_prepend(Elm_Entry *obj, Elm_Entry_Filter_Cb func, void *data);
 
+/**
+ * @brief Sets the prediction hint to use an intelligent reply suggestion
+ * service.
+ *
+ * @param[in] prediction_hint The prediction hint text.
+ *
+ * @since 1.20
+ *
+ * @ingroup Elm_Entry
+ */
+EAPI void elm_entry_prediction_hint_set(Elm_Entry *obj, const char *prediction_hint);
+
 #endif
