@@ -20,10 +20,11 @@ typedef Eo Elm_Interface_Scrollable;
  */
 typedef enum
 {
-  ELM_SCROLLER_POLICY_AUTO = 0, /** Show scrollbars as needed */
-  ELM_SCROLLER_POLICY_ON, /** Always show scrollbars */
-  ELM_SCROLLER_POLICY_OFF, /** Never show scrollbars */
-  ELM_SCROLLER_POLICY_LAST
+  ELM_SCROLLER_POLICY_AUTO = 0, /**< Show scrollbars as needed */
+  ELM_SCROLLER_POLICY_ON, /**< Always show scrollbars */
+  ELM_SCROLLER_POLICY_OFF, /**< Never show scrollbars */
+  ELM_SCROLLER_POLICY_LAST /**< Sentinel value to indicate last enum field
+                            * during iteration */
 } Elm_Scroller_Policy;
 
 /**
@@ -35,11 +36,12 @@ typedef enum
  */
 typedef enum
 {
-  ELM_SCROLLER_SINGLE_DIRECTION_NONE = 0, /** Scroll every direction */
-  ELM_SCROLLER_SINGLE_DIRECTION_SOFT, /** Scroll single direction if the
+  ELM_SCROLLER_SINGLE_DIRECTION_NONE = 0, /**< Scroll every direction */
+  ELM_SCROLLER_SINGLE_DIRECTION_SOFT, /**< Scroll single direction if the
                                        * direction is certain */
-  ELM_SCROLLER_SINGLE_DIRECTION_HARD, /** Scroll only single direction */
-  ELM_SCROLLER_SINGLE_DIRECTION_LAST
+  ELM_SCROLLER_SINGLE_DIRECTION_HARD, /**< Scroll only single direction */
+  ELM_SCROLLER_SINGLE_DIRECTION_LAST /**< Sentinel value to indicate last enum
+                                      * field during iteration */
 } Elm_Scroller_Single_Direction;
 
 /** Type that blocks the scroll movement in one or more direction.
@@ -50,11 +52,11 @@ typedef enum
  */
 typedef enum
 {
-  ELM_SCROLLER_MOVEMENT_NO_BLOCK = 1 /* 1 << 0 */, /** Do not block movements
+  ELM_SCROLLER_MOVEMENT_NO_BLOCK = 1 /* 1 >> 0 */, /**< Do not block movements
                                                     */
-  ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL = 2 /* 1 << 1 */, /** Block vertical
+  ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL = 2 /* 1 >> 1 */, /**< Block vertical
                                                           * movements */
-  ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL = 4 /* 1 << 2 */ /** Block horizontal
+  ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL = 4 /* 1 >> 2 */ /**< Block horizontal
                                                            * movements */
 } Elm_Scroller_Movement_Block;
 
@@ -66,7 +68,7 @@ typedef enum
  */
 #define ELM_INTERFACE_SCROLLABLE_MIXIN elm_interface_scrollable_mixin_get()
 
-EWAPI const Eo_Class *elm_interface_scrollable_mixin_get(void);
+EWAPI const Efl_Class *elm_interface_scrollable_mixin_get(void);
 
 /**
  * @brief Control scrolling gravity on the scrollable
@@ -146,14 +148,17 @@ EOAPI void elm_interface_scrollable_bounce_allow_get(const Eo *obj, Eina_Bool *h
  * @brief Control Wheel disable Enable or disable mouse wheel to be used to
  * scroll the scroller content. heel is enabled by default.
  *
- * @param[in] disabled
+ * @param[in] disabled @c true if wheel is disabled, @c false otherwise
  *
  * @ingroup Elm_Interface_Scrollable
  */
 EOAPI void elm_interface_scrollable_wheel_disabled_set(Eo *obj, Eina_Bool disabled);
 
-/** Control Wheel disable Enable or disable mouse wheel to be used to scroll
- * the scroller content. heel is enabled by default.
+/**
+ * @brief Control Wheel disable Enable or disable mouse wheel to be used to
+ * scroll the scroller content. heel is enabled by default.
+ *
+ * @return @c true if wheel is disabled, @c false otherwise
  *
  * @ingroup Elm_Interface_Scrollable
  */
@@ -201,8 +206,22 @@ EOAPI void elm_interface_scrollable_movement_block_set(Eo *obj, Elm_Scroller_Mov
  */
 EOAPI Elm_Scroller_Movement_Block elm_interface_scrollable_movement_block_get(const Eo *obj);
 
+/**
+ * @brief Momentum animator
+ *
+ * @param[in] disabled @c true if disabled, @c false otherwise
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
 EOAPI void elm_interface_scrollable_momentum_animator_disabled_set(Eo *obj, Eina_Bool disabled);
 
+/**
+ * @brief Momentum animator
+ *
+ * @return @c true if disabled, @c false otherwise
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
 EOAPI Eina_Bool elm_interface_scrollable_momentum_animator_disabled_get(const Eo *obj);
 
 /**
@@ -253,7 +272,7 @@ EOAPI void elm_interface_scrollable_policy_get(const Eo *obj, Elm_Scroller_Polic
  *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI void elm_interface_scrollable_content_region_set(Eo *obj, Evas_Coord x, Evas_Coord y, Evas_Coord w, Evas_Coord h);
+EOAPI void elm_interface_scrollable_content_region_set(Eo *obj, int x, int y, int w, int h);
 
 /**
  * @brief Currently visible content region
@@ -273,20 +292,24 @@ EOAPI void elm_interface_scrollable_content_region_set(Eo *obj, Evas_Coord x, Ev
  *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI void elm_interface_scrollable_content_region_get(const Eo *obj, Evas_Coord *x, Evas_Coord *y, Evas_Coord *w, Evas_Coord *h);
+EOAPI void elm_interface_scrollable_content_region_get(const Eo *obj, int *x, int *y, int *w, int *h);
 
 /**
  * @brief It decides whether the scrollable object propagates the events to
  * content object or not.
  *
- * @param[in] repeat_events
+ * @param[in] repeat_events @c true if events are propagated, @c false
+ * otherwise
  *
  * @ingroup Elm_Interface_Scrollable
  */
 EOAPI void elm_interface_scrollable_repeat_events_set(Eo *obj, Eina_Bool repeat_events);
 
-/** It decides whether the scrollable object propagates the events to content
- * object or not.
+/**
+ * @brief It decides whether the scrollable object propagates the events to
+ * content object or not.
+ *
+ * @return @c true if events are propagated, @c false otherwise
  *
  * @ingroup Elm_Interface_Scrollable
  */
@@ -311,7 +334,7 @@ EOAPI Eina_Bool elm_interface_scrollable_repeat_events_get(const Eo *obj);
  *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI void elm_interface_scrollable_page_size_set(Eo *obj, Evas_Coord x, Evas_Coord y);
+EOAPI void elm_interface_scrollable_page_size_set(Eo *obj, int x, int y);
 
 /**
  * @brief Scroll page size relative to viewport size.
@@ -332,14 +355,45 @@ EOAPI void elm_interface_scrollable_page_size_set(Eo *obj, Evas_Coord x, Evas_Co
  *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI void elm_interface_scrollable_page_size_get(const Eo *obj, Evas_Coord *x, Evas_Coord *y);
+EOAPI void elm_interface_scrollable_page_size_get(const Eo *obj, int *x, int *y);
 
+/**
+ * @brief Bounce animator
+ *
+ * @param[in] disabled @c true if bounce animation is disabled, @c false
+ * otherwise
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
 EOAPI void elm_interface_scrollable_bounce_animator_disabled_set(Eo *obj, Eina_Bool disabled);
 
+/**
+ * @brief Bounce animator
+ *
+ * @return @c true if bounce animation is disabled, @c false otherwise
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
 EOAPI Eina_Bool elm_interface_scrollable_bounce_animator_disabled_get(const Eo *obj);
 
+/**
+ * @brief Page scroll limit
+ *
+ * @param[in] page_limit_h Page limit horizontal
+ * @param[in] page_limit_v Page limit vertical
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
 EOAPI void elm_interface_scrollable_page_scroll_limit_set(Eo *obj, int page_limit_h, int page_limit_v);
 
+/**
+ * @brief Page scroll limit
+ *
+ * @param[out] page_limit_h Page limit horizontal
+ * @param[out] page_limit_v Page limit vertical
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
 EOAPI void elm_interface_scrollable_page_scroll_limit_get(const Eo *obj, int *page_limit_h, int *page_limit_v);
 
 /**
@@ -384,9 +438,29 @@ EOAPI void elm_interface_scrollable_page_snap_allow_set(Eo *obj, Eina_Bool horiz
  */
 EOAPI void elm_interface_scrollable_page_snap_allow_get(const Eo *obj, Eina_Bool *horiz, Eina_Bool *vert);
 
-EOAPI void elm_interface_scrollable_paging_set(Eo *obj, double pagerel_h, double pagerel_v, Evas_Coord pagesize_h, Evas_Coord pagesize_v);
+/**
+ * @brief Pagin property
+ *
+ * @param[in] pagerel_h Page relation horizontal
+ * @param[in] pagerel_v Page relation vertical
+ * @param[in] pagesize_h Page size horizontal
+ * @param[in] pagesize_v Page size vertical
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
+EOAPI void elm_interface_scrollable_paging_set(Eo *obj, double pagerel_h, double pagerel_v, int pagesize_h, int pagesize_v);
 
-EOAPI void elm_interface_scrollable_paging_get(const Eo *obj, double *pagerel_h, double *pagerel_v, Evas_Coord *pagesize_h, Evas_Coord *pagesize_v);
+/**
+ * @brief Pagin property
+ *
+ * @param[out] pagerel_h Page relation horizontal
+ * @param[out] pagerel_v Page relation vertical
+ * @param[out] pagesize_h Page size horizontal
+ * @param[out] pagesize_v Page size vertical
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
+EOAPI void elm_interface_scrollable_paging_get(const Eo *obj, double *pagerel_h, double *pagerel_v, int *pagesize_h, int *pagesize_v);
 
 /**
  * @brief Single direction scroll configuration
@@ -428,9 +502,25 @@ EOAPI void elm_interface_scrollable_single_direction_set(Eo *obj, Elm_Scroller_S
  */
 EOAPI Elm_Scroller_Single_Direction elm_interface_scrollable_single_direction_get(const Eo *obj);
 
-EOAPI void elm_interface_scrollable_step_size_set(Eo *obj, Evas_Coord x, Evas_Coord y);
+/**
+ * @brief Step size
+ *
+ * @param[in] x X coordinate
+ * @param[in] y Y coordinate
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
+EOAPI void elm_interface_scrollable_step_size_set(Eo *obj, int x, int y);
 
-EOAPI void elm_interface_scrollable_step_size_get(const Eo *obj, Evas_Coord *x, Evas_Coord *y);
+/**
+ * @brief Step size
+ *
+ * @param[out] x X coordinate
+ * @param[out] y Y coordinate
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
+EOAPI void elm_interface_scrollable_step_size_get(const Eo *obj, int *x, int *y);
 
 /**
  * @brief Controls an infinite loop for a scroller.
@@ -483,12 +573,19 @@ EOAPI void elm_interface_scrollable_hbar_drag_cb_set(Eo *obj, Elm_Interface_Scro
  */
 EOAPI void elm_interface_scrollable_drag_start_cb_set(Eo *obj, Elm_Interface_Scrollable_Cb drag_start_cb);
 
+/**
+ * @brief Freeze property
+ *
+ * @param[in] freeze @c true if freeze, @c false otherwise
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
 EOAPI void elm_interface_scrollable_freeze_set(Eo *obj, Eina_Bool freeze);
 
 /**
  * @brief When the viewport is resized, the callback is called.
  *
- * @param[in] viewport_resize_cb
+ * @param[in] viewport_resize_cb The callback
  *
  * @ingroup Elm_Interface_Scrollable
  */
@@ -539,6 +636,13 @@ EOAPI void elm_interface_scrollable_hbar_unpress_cb_set(Eo *obj, Elm_Interface_S
  */
 EOAPI void elm_interface_scrollable_drag_stop_cb_set(Eo *obj, Elm_Interface_Scrollable_Cb drag_stop_cb);
 
+/**
+ * @brief Extern pan
+ *
+ * @param[in] pan Pan object
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
 EOAPI void elm_interface_scrollable_extern_pan_set(Eo *obj, Efl_Canvas_Object *pan);
 
 /**
@@ -550,6 +654,13 @@ EOAPI void elm_interface_scrollable_extern_pan_set(Eo *obj, Efl_Canvas_Object *p
  */
 EOAPI void elm_interface_scrollable_page_change_cb_set(Eo *obj, Elm_Interface_Scrollable_Cb page_change_cb);
 
+/**
+ * @brief Hold property
+ *
+ * @param[in] hold @c true if hold, @c false otherwise
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
 EOAPI void elm_interface_scrollable_hold_set(Eo *obj, Eina_Bool hold);
 
 /**
@@ -573,8 +684,8 @@ EOAPI void elm_interface_scrollable_scroll_down_cb_set(Eo *obj, Elm_Interface_Sc
 /**
  * @brief Set scroll page size relative to viewport size.
  *
- * @param[in] h_pagerel
- * @param[in] v_pagerel
+ * @param[in] h_pagerel Page relation horizontal
+ * @param[in] v_pagerel Page relation vertical
  *
  * @ingroup Elm_Interface_Scrollable
  */
@@ -598,8 +709,22 @@ EOAPI void elm_interface_scrollable_scroll_cb_set(Eo *obj, Elm_Interface_Scrolla
  */
 EOAPI void elm_interface_scrollable_animate_stop_cb_set(Eo *obj, Elm_Interface_Scrollable_Cb animate_stop_cb);
 
+/**
+ * @brief Mirroed property
+ *
+ * @param[in] mirrored @c true if mirrored, @c false otherwise
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
 EOAPI void elm_interface_scrollable_mirrored_set(Eo *obj, Eina_Bool mirrored);
 
+/**
+ * @brief set the callback to run on minimal limit content
+ *
+ * @param[in] min_limit_cb The callback
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
 EOAPI void elm_interface_scrollable_content_min_limit_cb_set(Eo *obj, Elm_Interface_Scrollable_Min_Limit_Cb min_limit_cb);
 
 /**
@@ -611,6 +736,13 @@ EOAPI void elm_interface_scrollable_content_min_limit_cb_set(Eo *obj, Elm_Interf
  */
 EOAPI void elm_interface_scrollable_scroll_right_cb_set(Eo *obj, Elm_Interface_Scrollable_Cb scroll_right_cb);
 
+/**
+ * @brief Content property
+ *
+ * @param[in] content Content object
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
 EOAPI void elm_interface_scrollable_content_set(Eo *obj, Efl_Canvas_Object *content);
 
 /**
@@ -671,6 +803,14 @@ EOAPI void elm_interface_scrollable_edge_right_cb_set(Eo *obj, Elm_Interface_Scr
  */
 EOAPI void elm_interface_scrollable_edge_top_cb_set(Eo *obj, Elm_Interface_Scrollable_Cb edge_top_cb);
 
+/**
+ * @brief Object property
+ *
+ * @param[in] edje_object Edje object
+ * @param[in] hit_rectangle Evas object
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
 EOAPI void elm_interface_scrollable_objects_set(Eo *obj, Efl_Canvas_Object *edje_object, Efl_Canvas_Object *hit_rectangle);
 
 /**
@@ -709,7 +849,17 @@ EOAPI void elm_interface_scrollable_last_page_get(const Eo *obj, int *pagenumber
  */
 EOAPI void elm_interface_scrollable_current_page_get(const Eo *obj, int *pagenumber_h, int *pagenumber_v);
 
-EOAPI void elm_interface_scrollable_content_viewport_geometry_get(const Eo *obj, Evas_Coord *x, Evas_Coord *y, Evas_Coord *w, Evas_Coord *h);
+/**
+ * @brief Content viewport geometry
+ *
+ * @param[out] x X coordinate
+ * @param[out] y Y coordinate
+ * @param[out] w Width
+ * @param[out] h Height
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
+EOAPI void elm_interface_scrollable_content_viewport_geometry_get(const Eo *obj, int *x, int *y, int *w, int *h);
 
 /**
  * @brief Get the size of the content object
@@ -721,11 +871,29 @@ EOAPI void elm_interface_scrollable_content_viewport_geometry_get(const Eo *obj,
  *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI void elm_interface_scrollable_content_size_get(const Eo *obj, Evas_Coord *w, Evas_Coord *h);
+EOAPI void elm_interface_scrollable_content_size_get(const Eo *obj, int *w, int *h);
 
-EOAPI void elm_interface_scrollable_content_pos_set(Eo *obj, Evas_Coord x, Evas_Coord y, Eina_Bool sig);
+/**
+ * @brief Set the content position
+ *
+ * @param[in] x X coordinate
+ * @param[in] y Y coordinate
+ * @param[in] sig Send signals to the theme corresponding to the scroll
+ * direction, or if an edge was reached.
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
+EOAPI void elm_interface_scrollable_content_pos_set(Eo *obj, int x, int y, Eina_Bool sig);
 
-EOAPI void elm_interface_scrollable_content_pos_get(Eo *obj, Evas_Coord *x, Evas_Coord *y);
+/**
+ * @brief Get content position
+ *
+ * @param[out] x X coordinate
+ * @param[out] y Y coordinate
+ *
+ * @ingroup Elm_Interface_Scrollable
+ */
+EOAPI void elm_interface_scrollable_content_pos_get(Eo *obj, int *x, int *y);
 
 /**
  * @brief Show a specific virtual region within the scroller content object by
@@ -763,7 +931,7 @@ EOAPI void elm_interface_scrollable_page_show(Eo *obj, int pagenumber_h, int pag
  *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI void elm_interface_scrollable_region_bring_in(Eo *obj, Evas_Coord x, Evas_Coord y, Evas_Coord w, Evas_Coord h);
+EOAPI void elm_interface_scrollable_region_bring_in(Eo *obj, int x, int y, int w, int h);
 
 /**
  * @brief Show a specific virtual region within the scroller content object by
@@ -795,7 +963,7 @@ EOAPI void elm_interface_scrollable_page_bring_in(Eo *obj, int pagenumber_h, int
  *
  * @ingroup Elm_Interface_Scrollable
  */
-EOAPI void elm_interface_scrollable_content_region_show(Eo *obj, Evas_Coord x, Evas_Coord y, Evas_Coord w, Evas_Coord h);
+EOAPI void elm_interface_scrollable_content_region_show(Eo *obj, int x, int y, int w, int h);
 
 /**
  * @brief Prevent the scrollable from being smaller than the minimum size of
@@ -806,17 +974,18 @@ EOAPI void elm_interface_scrollable_content_region_show(Eo *obj, Evas_Coord x, E
  * horizontally and/or vertically to perfectly fit its content in that
  * direction.
  *
- * @param[in] w whether to limit the minimum horizontal size
- * @param[in] h whether to limit the minimum vertical size
+ * @param[in] w Whether to limit the minimum horizontal size
+ * @param[in] h Whether to limit the minimum vertical size
  *
  * @ingroup Elm_Interface_Scrollable
  */
 EOAPI void elm_interface_scrollable_content_min_limit(Eo *obj, Eina_Bool w, Eina_Bool h);
 
-EOAPI extern const Eo_Event_Description _ELM_INTERFACE_SCROLLABLE_EVENT_CHANGED;
+EWAPI extern const Efl_Event_Description _ELM_INTERFACE_SCROLLABLE_EVENT_CHANGED;
 
-/**
- * No description
+/** Called when content changed
+ *
+ * @ingroup Elm_Interface_Scrollable
  */
 #define ELM_INTERFACE_SCROLLABLE_EVENT_CHANGED (&(_ELM_INTERFACE_SCROLLABLE_EVENT_CHANGED))
 
