@@ -13,9 +13,12 @@ typedef Eo Elm_Player_Internal_Part;
 
 
 #endif
+/** Elementary player internal part class
+ *
+ * @ingroup Elm_Player_Internal_Part
+ */
 #define ELM_PLAYER_INTERNAL_PART_CLASS elm_player_internal_part_class_get()
 
-EWAPI const Eo_Class *elm_player_internal_part_class_get(void);
-
+EWAPI const Efl_Class *elm_player_internal_part_class_get(void);
 
 #endif
