@@ -14,34 +14,11 @@ typedef Eo Elm_Scroller;
 
 #endif
 
-/**
- * @brief Set event propagation on a scroller
- *
- * This enables or disables event propagation from the scroller content to the
- * scroller and its parent. By default event propagation is enabled.
- *
- * @param[in] propagation The propagation state
- *
- * @ingroup Elm_Scroller
- */
-EAPI void elm_scroller_propagate_events_set(Elm_Scroller *obj, Eina_Bool propagation);
-
-/**
- * @brief Get event propagation for a scroller
- *
- * This gets the event propagation for a scroller.
- *
- * @return The propagation state
- *
- * @ingroup Elm_Scroller
- */
-EAPI Eina_Bool elm_scroller_propagate_events_get(const Elm_Scroller *obj);
-
 /**
  * @brief Set custom theme elements for the scroller
  *
- * @param[in] klass
- * @param[in] group
+ * @param[in] klass Klass name
+ * @param[in] group Group name
  *
  * @ingroup Elm_Scroller
  */
