@@ -13,15 +13,19 @@ typedef Eo Evas_VG;
 
 
 #endif
+/** Efl vector graphics class
+ *
+ * @ingroup Evas_VG
+ */
 #define EVAS_VG_CLASS evas_vg_class_get()
 
-EWAPI const Eo_Class *evas_vg_class_get(void);
+EWAPI const Efl_Class *evas_vg_class_get(void);
 
 /**
  * @brief Get the root node of the evas_object_vg.
  *
  * @note To manually create the shape object and show in the Vg object canvas
- * you must create the hirarchy and set the parent as root node.
+ * you must create the hierarchy and set the parent as root node.
  *
  * @return Root node of the VG canvas.
  *
@@ -29,7 +33,6 @@ EWAPI const Eo_Class *evas_vg_class_get(void);
  *
  * @ingroup Evas_VG
  */
-EOAPI Eo_Base *evas_obj_vg_root_node_get(const Eo *obj);
-
+EOAPI Efl_Object *evas_obj_vg_root_node_get(const Eo *obj);
 
 #endif
